﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Common;
using System.Text;
using Microsoft.Practices.EnterpriseLibrary.Data;
using DotNetCore.BannerManagement.Domain;
using System.Data.SqlClient;
using System.Diagnostics;
using Microsoft.Practices.Repository;
using Microsoft.Practices.Repository.SQLServer;

namespace DotNetCore.BannerManagement.DAL.Domain.CountRepositoryArtifacts
{
    /// <summary>
    /// Respository that lets you find Count in the
    /// CRM database.
    /// </summary>
    public class CountRepository : Repository<Count>, ICountRepository
    {
        public CountRepository(string databaseName)
            : base(databaseName)
        {
        }

        public CountRepository()
            : base()
        {
        }


        public Count GetImpressionsByAdvertisementID(System.Int32 advertisementId)
        {
            ISelectionFactory<System.Int32> selectionFactory = new GetImpressionsByAdvertisementIDSelectionFactory();

            try
            {
                return base.FindOne(selectionFactory, new GetImpressionsByAdvertisementIDFactory(), advertisementId);
            }
            catch (SqlException ex)
            {
                HandleSqlException(ex, selectionFactory);
            }

            return new Count();
        }

        public Count GetClickThroughsByAdvertisementID(System.Int32 advertisementId)
        {
            ISelectionFactory<System.Int32> selectionFactory = new GetClickThroughsByAdvertisementIDSelectionFactory();

            try
            {
                return base.FindOne(selectionFactory, new GetClickThroughsByAdvertisementIDFactory(), advertisementId);
            }
            catch (SqlException ex)
            {
                HandleSqlException(ex, selectionFactory);
            }

            return new Count();
        }

        private void HandleSqlException(SqlException ex, IDbToBusinessEntityNameMapper mapper)
        {
            if (ex.Number == ErrorCodes.SqlUserRaisedError)
            {
                switch (ex.State)
                {
                    case ErrorCodes.ValidationError:
                        string[] messageParts = ex.Errors[0].Message.Split(':');
                        throw new RepositoryValidationException(
                            mapper.MapDbParameterToBusinessEntityProperty(messageParts[0]),
                            messageParts[1], ex);

                    case ErrorCodes.ConcurrencyViolationError:
                        throw new ConcurrencyViolationException(ex.Message, ex);

                }
            }

            throw new RepositoryFailureException(ex);
        }
    }
}

