﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Common;
using System.Text;
using Microsoft.Practices.EnterpriseLibrary.Data;
using DotNetCore.BannerManagement.Domain;
using Microsoft.Practices.Repository;

using System.Globalization;

namespace DotNetCore.BannerManagement.DAL.Domain.CountRepositoryArtifacts
{
    /// <summary>
    /// This class is responsible for turning a selection criteria
    /// into a select statement and database query parameters.
    /// </summary>
    internal class GetClickThroughsByAdvertisementIDSelectionFactory : ISelectionFactory<System.Int32>
    {
        /// <summary>
        /// Creates the GetClickThroughsByAdvertisementIDSelectionFactory to build a select statement for
        /// the given System.Int32.
        /// </summary>
        /// <param name="System.Int32">System.Int32 to select from the database.</param>      
        public GetClickThroughsByAdvertisementIDSelectionFactory()
        {
        }

        #region ISelectionFactory<System.Int32> Members
        public DbCommand ConstructSelectCommand(Database db, System.Int32 advertisementId)
        {

            DbCommand command = db.GetStoredProcCommand("dbo.GetClickThroughsByAdvertisementID");
            db.AddInParameter(command, "advertisementId", DbType.Int32, advertisementId);
            return command;
        }
        #endregion

        #region IDbToBusinessEntityNameMapper Members
        /// <summary>
        /// Maps a field name in the database (usually a parameter name for a stored proc)
        /// to the corresponding business entity property name.
        /// </summary>
        /// <remarks>This method is intended for error message handling, not for reflection.</remarks>
        /// <param name="dbParameter">Name of field/parameter that the database knows about.</param>
        /// <returns>Corresponding business entity field name.</returns>
        public string MapDbParameterToBusinessEntityProperty(string dbParameter)
        {
            switch (dbParameter)
            {
                case "advertisementId":
                    return "advertisementId";
                default:
                    throw new Exception(dbParameter);
            }
        }
        #endregion
    }
}

