﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Common;
using System.Text;
using Microsoft.Practices.EnterpriseLibrary.Data;
using DotNetCore.BannerManagement.Domain;
using Microsoft.Practices.Repository;

using System.Globalization;

namespace DotNetCore.BannerManagement.DAL.Domain.dnc_ImageRepositoryArtifacts
{
    /// <summary>
    /// A factory object that is responsible for taking a dnc_Image
    /// and generating the corresponding SQL to insert that
    /// dnc_Image into the database. It also includes a method
    /// to grab the returned ID from the call and updating the
    /// dnc_Image object with it.
    /// </summary>
    internal class dnc_ImageInsertFactory : IDbToBusinessEntityNameMapper, IInsertFactory<dnc_Image>
    {
        /// <summary>
        /// Creates the dnc_ImageInsertFactory to build an insert statement for
        /// the given dnc_Image object.
        /// </summary>
        /// <param name="dnc_Image">New dnc_Image to insert into the database.</param>
        public dnc_ImageInsertFactory()
        {
        }



		#region IInsertFactory<dnc_Image> Members
		
        public DbCommand ConstructInsertCommand(Database db, dnc_Image dnc_Image)
        {            
			DbCommand command = db.GetStoredProcCommand("dbo.Insertdnc_Image");
			
			if(dnc_Image.ContentType != null)
			{
				db.AddInParameter(command, "contentType", DbType.String, dnc_Image.ContentType);
			}
				db.AddInParameter(command, "height", DbType.Decimal, dnc_Image.Height);
			db.AddOutParameter(command, "iD", DbType.Int32, 4);
				db.AddInParameter(command, "image", DbType.Binary, dnc_Image.Image);
			if(dnc_Image.Name != null)
			{
				db.AddInParameter(command, "name", DbType.String, dnc_Image.Name);
			}
				db.AddInParameter(command, "width", DbType.Decimal, dnc_Image.Width);
			return command;
        }

        public void SetNewID(Database db, DbCommand command, dnc_Image dnc_Image)
        {
            System.Int32 id1 = (System.Int32)(db.GetParameterValue(command, "iD"));
	dnc_Image.ID = id1;
	
        }
        
        #endregion
        
		#region IDbToBusinessEntityNameMapper Members
        /// <summary>
        /// Maps a field name in the database (usually a parameter name for a stored proc)
        /// to the corresponding business entity property name.
        /// </summary>
        /// <remarks>This method is intended for error message handling, not for reflection.</remarks>
        /// <param name="dbParameter">Name of field/parameter that the database knows about.</param>
        /// <returns>Corresponding business entity field name.</returns>
        public string MapDbParameterToBusinessEntityProperty(string dbParameter)
        {
            switch (dbParameter)
            {
				case "contentType":
					return "ContentType";
				case "height":
					return "Height";
				case "image":
					return "Image";
				case "name":
					return "Name";
				case "width":
					return "Width";
				default:
					throw new Exception(dbParameter);
			}
        }
        #endregion        
    }

}

